@@ -15,6 +15,7 @@ from .element import ElementPlot
 from .renderer import PlotlyRenderer
 
 from .annotation import *            # noqa (API import)
+from .tiles import *                 # noqa (API import)
 from .element import *               # noqa (API import)
 from .chart import *                 # noqa (API import)
 from .chart3d import *               # noqa (API import)
@@ -26,7 +27,7 @@ from .callbacks import *             # noqa (API import)
 from .shapes import *                # noqa (API import)
 from .images import *                # noqa (API import)
 
-if LooseVersion(plotly.__version__) < '4.0.0':
+if LooseVersion(plotly.__version__) < LooseVersion('4.0.0'):
     raise VersionError(
         "The plotly extension requires a plotly version >=4.0.0, "
         "please upgrade from plotly %s to a more recent version."
@@ -72,6 +73,7 @@ Store.register({Points: ScatterPlot,
 
                 # Annotations
                 Labels: LabelPlot,
+                Tiles: TilePlot,
 
                 # Shapes
                 Box: PathShapePlot,
@@ -89,6 +91,7 @@ Store.register({Points: ScatterPlot,
                 Overlay: OverlayPlot,
                 NdOverlay: OverlayPlot,
                 Layout: LayoutPlot,
+                AdjointLayout: AdjointLayoutPlot,
                 NdLayout: LayoutPlot,
                 GridSpace: GridPlot,
                 GridMatrix: GridPlot}, backend='plotly')
@@ -100,7 +103,8 @@ if config.no_padding:
     for plot in concrete_descendents(ElementPlot).values():
         plot.padding = 0
 
-dflt_cmap = 'fire'
+dflt_cmap = config.default_cmap
+dflt_shape_line_color = '#2a3f5f'  # Line color of default plotly template
 
 point_size = np.sqrt(6) # Matches matplotlib default
 Cycle.default_cycles['default_colors'] =  ['#30a2da', '#fc4f30', '#e5ae38',
@@ -109,18 +113,23 @@ Cycle.default_cycles['default_colors'] =  ['#30a2da', '#fc4f30', '#e5ae38',
 # Charts
 options.Curve = Options('style', color=Cycle(), line_width=2)
 options.ErrorBars = Options('style', color='black')
-options.Scatter = Options('style', color=Cycle())
-options.Points = Options('style', color=Cycle())
+options.Scatter = Options('style', color=Cycle(), cmap=dflt_cmap)
+options.Points = Options('style', color=Cycle(), cmap=dflt_cmap)
 options.Area = Options('style', color=Cycle(), line_width=2)
 options.Spread = Options('style', color=Cycle(), line_width=2)
-options.TriSurface = Options('style', cmap='viridis')
+options.TriSurface = Options('style', cmap=dflt_cmap)
 options.Histogram = Options('style', color=Cycle(), line_width=1, line_color='black')
 
 # Rasters
-options.Image = Options('style', cmap=dflt_cmap)
-options.Raster = Options('style', cmap=dflt_cmap)
-options.QuadMesh = Options('style', cmap=dflt_cmap)
-options.HeatMap = Options('style', cmap='RdBu_r')
+options.Image = Options('style', cmap=config.default_gridded_cmap)
+options.Raster = Options('style', cmap=config.default_gridded_cmap)
+options.QuadMesh = Options('style', cmap=config.default_gridded_cmap)
+options.HeatMap = Options('style', cmap=config.default_heatmap_cmap)
+
+# Disable padding for image-like elements
+options.Image = Options("plot", padding=0)
+options.Raster = Options("plot", padding=0)
+options.RGB = Options("plot", padding=0)
 
 # 3D
 options.Scatter3D = Options('style', color=Cycle(), size=6)
@@ -128,3 +137,10 @@ options.Scatter3D = Options('style', color=Cycle(), size=6)
 # Annotations
 options.VSpan = Options('style', fillcolor=Cycle(), opacity=0.5)
 options.HSpan = Options('style', fillcolor=Cycle(), opacity=0.5)
+
+# Shapes
+options.Rectangles = Options('style', line_color=dflt_shape_line_color)
+options.Bounds = Options('style', line_color=dflt_shape_line_color)
+options.Path = Options('style', line_color=dflt_shape_line_color)
+options.Segments = Options('style', line_color=dflt_shape_line_color)
+options.Box = Options('style', line_color=dflt_shape_line_color)
