@@ -10,8 +10,7 @@ import param
 
 from ..core.data import PandasInterface
 from ..core.dimension import Dimension
-from ..core.util import basestring, pd, resolve_dependent_value, unique_iterator
-
+from ..core.util import basestring, flatten, pd, resolve_dependent_value, unique_iterator
 
 def _maybe_map(numpy_fn):
     def fn(values, *args, **kwargs):
@@ -219,6 +218,7 @@ class dim(object):
     _accessor = None
 
     def __init__(self, obj, *args, **kwargs):
+        from panel.widgets import Widget
         ops = []
         self._ns = np.ndarray
         self.coerce = kwargs.get('coerce', True)
@@ -226,6 +226,10 @@ class dim(object):
             self.dimension = Dimension(obj)
         elif isinstance(obj, Dimension):
             self.dimension = obj
+        elif isinstance(obj, param.Parameter):
+            self.dimension = obj
+        elif isinstance(obj, Widget):
+            self.dimension = obj.param.value
         else:
             self.dimension = obj.dimension
             ops = obj.ops
@@ -242,6 +246,12 @@ class dim(object):
                           'reverse': kwargs.pop('reverse', False)}]
         self.ops = ops
 
+    def __getstate__(self):
+        return self.__dict__
+
+    def __setstate__(self, state):
+        self.__dict__.update(state)
+
     @property
     def _current_accessor(self):
         if self.ops and self.ops[-1]['kwargs'].get('accessor'):
@@ -261,11 +271,25 @@ class dim(object):
             new_op = dict(op, args=args, kwargs=kwargs)
         return self.clone(self.dimension, self.ops[:-1]+[new_op])
 
-    def __getattr__(self, attr):
-        if attr in dir(self):
+    def __getattribute__(self, attr):
+        self_dict = super(dim, self).__getattribute__('__dict__')
+        if '_ns' not in self_dict: # Not yet initialized
+            return super(dim, self).__getattribute__(attr)
+        ns = self_dict['_ns']
+        ops = super(dim, self).__getattribute__('ops')
+        if ops and ops[-1]['kwargs'].get('accessor'):
+            try:
+                ns = getattr(ns, ops[-1]['fn'])
+            except Exception:
+                # If the namespace doesn't know the method we are
+                # calling then we are using custom API of the dim
+                # transform itself, so set namespace to None
+                ns = None
+        extras = {ns_attr for ns_attr in dir(ns) if not ns_attr.startswith('_')}
+        if attr in extras and attr not in super(dim, self).__dir__():
             return type(self)(self, attr, accessor=True)
-        raise AttributeError("%r object has no attribute %r" %
-                             (type(self).__name__, attr))
+        else:
+            return super(dim, self).__getattribute__(attr)
 
     def __dir__(self):
         ns = self._ns
@@ -307,18 +331,28 @@ class dim(object):
         params = {}
         for op in self.ops:
             op_args = list(op['args'])+list(op['kwargs'].values())
+            op_args = flatten(op_args)
             for op_arg in op_args:
                 if 'panel' in sys.modules:
                     from panel.widgets.base import Widget
                     if isinstance(op_arg, Widget):
                         op_arg = op_arg.param.value
+                if isinstance(op_arg, dim):
+                    params.update(op_arg.params)
+                elif isinstance(op_arg, slice):
+                    if isinstance(op_arg.start, param.Parameter):
+                        params[op_arg.start.name+str(id(op_arg.start))] = op_arg.start
+                    if isinstance(op_arg.stop, param.Parameter):
+                        params[op_arg.stop.name+str(id(op_arg.stop))] = op_arg.stop
+                    if isinstance(op_arg.step, param.Parameter):
+                        params[op_arg.step.name+str(id(op_arg.step))] = op_arg.step
                 if (isinstance(op_arg, param.Parameter) and
                     isinstance(op_arg.owner, param.Parameterized)):
-                    params[op_arg.name+str(id(op))] = op_arg
+                    params[op_arg.name+str(id(op_arg))] = op_arg
+
         return params
 
     # Namespace properties
-
     @property
     def df(self):
         return self.clone(dim_type=df_dim)
@@ -331,6 +365,9 @@ class dim(object):
     def xr(self):
         return self.clone(dim_type=xr_dim)
 
+    def __getitem__(self, *index):
+        return type(self)(self, operator.getitem, *index)
+
     # Builtin functions
     def __abs__(self):            return type(self)(self, abs)
     def __round__(self, ndigits=None):
@@ -391,7 +428,9 @@ class dim(object):
     def any(self, *args, **kwargs):      return type(self)(self, np.any, *args, **kwargs)
     def all(self, *args, **kwargs):      return type(self)(self, np.all, *args, **kwargs)
     def cumprod(self, *args, **kwargs):  return type(self)(self, np.cumprod,  *args, **kwargs)
-    def cumsum(self, *args, **kwargs):   return type(self)(self, np.cumsum,  *args, **kwargs)
+    def cumsum(self, *args, **kwargs):   return type(self)(self, np.cumsum,  *args,
+                                                           axis=kwargs.pop('axis',0),
+                                                           **kwargs)
     def max(self, *args, **kwargs):      return type(self)(self, np.max, *args, **kwargs)
     def mean(self, *args, **kwargs):     return type(self)(self, np.mean, *args, **kwargs)
     def min(self, *args, **kwargs):      return type(self)(self, np.min, *args, **kwargs)
@@ -493,8 +532,12 @@ class dim(object):
         """
         from ..element import Graph
 
-        if isinstance(self.dimension, dim):
+        if isinstance(self.dimension, param.Parameter):
+            applies = True
+        elif isinstance(self.dimension, dim):
             applies = self.dimension.applies(dataset)
+        elif self.dimension.name == '*':
+            applies = True
         else:
             lookup = self.dimension if strict else self.dimension.name
             applies = dataset.get_dimension(lookup) is not None
@@ -541,6 +584,12 @@ class dim(object):
                     dataset, flat, expanded, ranges, all_values,
                     keep_index, compute, strict
                 )
+            elif isinstance(arg, slice):
+                arg = slice(
+                    resolve_dependent_value(arg.start),
+                    resolve_dependent_value(arg.stop),
+                    resolve_dependent_value(arg.step)
+                )
             arg = resolve_dependent_value(arg)
             fn_args.append(arg)
         fn_kwargs = {}
@@ -550,6 +599,12 @@ class dim(object):
                     dataset, flat, expanded, ranges, all_values,
                     keep_index, compute, strict
                 )
+            elif isinstance(v, slice):
+                v = slice(
+                    resolve_dependent_value(v.start),
+                    resolve_dependent_value(v.stop),
+                    resolve_dependent_value(v.step)
+                )
             fn_kwargs[k] = resolve_dependent_value(v)
         args = tuple(fn_args[::-1] if op['reverse'] else fn_args)
         kwargs = dict(fn_kwargs)
@@ -660,18 +715,25 @@ class dim(object):
             compute_for_compute = compute
             keep_index_for_compute = keep_index
 
-        lookup = dimension if strict else dimension.name
-        eldim = dataset.get_dimension(lookup)
-        data = dataset.interface.values(
-            dataset, lookup, expanded=expanded, flat=flat,
-            compute=compute_for_compute, keep_index=keep_index_for_compute
-        )
+        if dimension.name == '*':
+            data = dataset.data
+            eldim = None
+        elif isinstance(dimension, param.Parameter):
+            data = getattr(dimension.owner, dimension.name)
+            eldim = None
+        else:
+            lookup = dimension if strict else dimension.name
+            eldim = dataset.get_dimension(lookup).name
+            data = dataset.interface.values(
+                dataset, lookup, expanded=expanded, flat=flat,
+                compute=compute_for_compute, keep_index=keep_index_for_compute
+            )
         for op in self.ops:
             fn, fn_name, args, kwargs, accessor = self._resolve_op(
                 op, dataset, data, flat, expanded, ranges, all_values,
                 keep_index_for_compute, compute_for_compute, strict
             )
-            drange = ranges.get(eldim.name, {})
+            drange = ranges.get(eldim, {})
             drange = drange.get('combined', drange)
             data = self._apply_fn(dataset, data, fn, fn_name, args,
                                   kwargs, accessor, drange)
@@ -756,7 +818,7 @@ class dim(object):
                     format_string += '{kwargs}'
 
             # Insert accessor
-            if i == 0 and self._accessor:
+            if i == 0 and self._accessor and ')' in format_string:
                 idx = format_string.index(')')
                 format_string = ''.join([
                     format_string[:idx], ').', self._accessor,
@@ -847,3 +909,74 @@ class xr_dim(dim):
         if self.interface_applies(dataset, coerce=False):
             return dataset
         return dataset.clone(datatype=['xarray'])
+
+
+def lon_lat_to_easting_northing(longitude, latitude):
+    """
+    Projects the given longitude, latitude values into Web Mercator
+    (aka Pseudo-Mercator or EPSG:3857) coordinates.
+
+    Longitude and latitude can be provided as scalars, Pandas columns,
+    or Numpy arrays, and will be returned in the same form.  Lists
+    or tuples will be converted to Numpy arrays.
+
+    Args:
+        longitude
+        latitude
+
+    Returns:
+        (easting, northing)
+
+    Examples:
+       easting, northing = lon_lat_to_easting_northing(-74,40.71)
+
+       easting, northing = lon_lat_to_easting_northing(
+           np.array([-74]),np.array([40.71])
+       )
+
+       df=pandas.DataFrame(dict(longitude=np.array([-74]),latitude=np.array([40.71])))
+       df.loc[:, 'longitude'], df.loc[:, 'latitude'] = lon_lat_to_easting_northing(
+           df.longitude,df.latitude
+       )
+    """
+    if isinstance(longitude, (list, tuple)):
+        longitude = np.array(longitude)
+    if isinstance(latitude, (list, tuple)):
+        latitude = np.array(latitude)
+
+    origin_shift = np.pi * 6378137
+    easting = longitude * origin_shift / 180.0
+    with np.errstate(divide='ignore', invalid='ignore'):
+        northing = np.log(
+            np.tan((90 + latitude) * np.pi / 360.0)
+        ) * origin_shift / np.pi
+    return easting, northing
+
+
+def easting_northing_to_lon_lat(easting, northing):
+    """
+    Projects the given easting, northing values into
+    longitude, latitude coordinates.
+
+    easting and northing values are assumed to be in Web Mercator
+    (aka Pseudo-Mercator or EPSG:3857) coordinates.
+
+    Args:
+        easting
+        northing
+
+    Returns:
+        (longitude, latitude)
+    """
+    if isinstance(easting, (list, tuple)):
+        easting = np.array(easting)
+    if isinstance(northing, (list, tuple)):
+        northing = np.array(northing)
+
+    origin_shift = np.pi * 6378137
+    longitude = easting * 180.0 / origin_shift
+    with np.errstate(divide='ignore'):
+        latitude = np.arctan(
+            np.exp(northing * np.pi / origin_shift)
+        ) * 360.0 / np.pi - 90
+    return longitude, latitude
